Index: /trunk/src/VBox/Frontends/VirtualBox/Makefile.kmk
===================================================================
--- /trunk/src/VBox/Frontends/VirtualBox/Makefile.kmk	(revision 76949)
+++ /trunk/src/VBox/Frontends/VirtualBox/Makefile.kmk	(revision 76950)
@@ -721,5 +721,4 @@
 	src/guestctrl/UIFileManagerOperationsPanel.h \
 	src/guestctrl/UIFileManagerOptionsPanel.h \
-	src/guestctrl/UIFileManagerPanel.h \
 	src/guestctrl/UIFileManagerSessionPanel.h \
 	src/guestctrl/UIFileManagerTable.h \
@@ -1159,5 +1158,4 @@
 	src/guestctrl/UIFileManagerOperationsPanel.cpp \
 	src/guestctrl/UIFileManagerOptionsPanel.cpp \
-	src/guestctrl/UIFileManagerPanel.cpp \
 	src/guestctrl/UIFileManagerSessionPanel.cpp \
 	src/guestctrl/UIFileManagerTable.cpp \
Index: /trunk/src/VBox/Frontends/VirtualBox/src/globals/UIDialogPanel.cpp
===================================================================
--- /trunk/src/VBox/Frontends/VirtualBox/src/globals/UIDialogPanel.cpp	(revision 76949)
+++ /trunk/src/VBox/Frontends/VirtualBox/src/globals/UIDialogPanel.cpp	(revision 76950)
@@ -33,5 +33,5 @@
 
 
-UIDialogPanel::UIDialogPanel(QWidget *pParent)
+UIDialogPanel::UIDialogPanel(QWidget *pParent /* = 0 */)
     : QIWithRetranslateUI<QWidget>(pParent)
     , m_pMainLayout(0)
Index: /trunk/src/VBox/Frontends/VirtualBox/src/globals/UIDialogPanel.h
===================================================================
--- /trunk/src/VBox/Frontends/VirtualBox/src/globals/UIDialogPanel.h	(revision 76949)
+++ /trunk/src/VBox/Frontends/VirtualBox/src/globals/UIDialogPanel.h	(revision 76950)
@@ -30,11 +30,9 @@
 /* Forward declarations: */
 class QHBoxLayout;
-class QPlainTextEdit;
-class QTextDocument;
 class QIToolButton;
 
 
-/** QWidget extension acting as the base class for UIVMLogViewerXXXPanel widgets. */
-class UIDialogPanel : public QIWithRetranslateUI<QWidget>
+/** QWidget extension acting as the base class for all the dialog panels like file manager, logviewer etc. */
+class SHARED_LIBRARY_STUFF UIDialogPanel : public QIWithRetranslateUI<QWidget>
 {
     Q_OBJECT;
@@ -42,5 +40,5 @@
 public:
 
-    UIDialogPanel(QWidget *pParent);
+    UIDialogPanel(QWidget *pParent = 0);
     void setCloseButtonShortCut(QKeySequence shortCut);
     virtual QString panelName() const = 0;
@@ -72,5 +70,4 @@
 private:
 
-    /** Holds the reference to VM Log-Viewer this panel belongs to. */
     QHBoxLayout   *m_pMainLayout;
     QIToolButton  *m_pCloseButton;
Index: /trunk/src/VBox/Frontends/VirtualBox/src/guestctrl/UIFileManager.cpp
===================================================================
--- /trunk/src/VBox/Frontends/VirtualBox/src/guestctrl/UIFileManager.cpp	(revision 76949)
+++ /trunk/src/VBox/Frontends/VirtualBox/src/guestctrl/UIFileManager.cpp	(revision 76950)
@@ -261,5 +261,5 @@
 
     pTopLayout->addLayout(pFileTableContainerLayout);
-    m_pSessionPanel = new UIFileManagerSessionPanel(this /* manager dialog */, 0 /*parent */);
+    m_pSessionPanel = new UIFileManagerSessionPanel;
     if (m_pSessionPanel)
     {
@@ -270,6 +270,5 @@
 
     m_pOptionsPanel =
-        new UIFileManagerOptionsPanel(this /* manager dialog */,
-                                                   0 /*parent */, UIFileManagerOptions::instance());
+        new UIFileManagerOptionsPanel(0 /*parent */, UIFileManagerOptions::instance());
     if (m_pOptionsPanel)
     {
@@ -284,5 +283,5 @@
 
     m_pOperationsPanel =
-        new UIFileManagerOperationsPanel(this /* manager dialog */, 0 /*parent */);
+        new UIFileManagerOperationsPanel;
     if (m_pOperationsPanel)
     {
@@ -295,5 +294,5 @@
     }
 
-    m_pLogPanel = new UIFileManagerLogPanel(this /* manager dialog */, 0 /*parent */);
+    m_pLogPanel = new UIFileManagerLogPanel;
     if (m_pLogPanel)
     {
@@ -356,5 +355,18 @@
         connect(m_pSessionPanel, &UIFileManagerSessionPanel::sigCloseSession,
                 this, &UIFileManager::sltCloseSession);
-    }
+        connect(m_pSessionPanel, &UIFileManagerSessionPanel::sigHidePanel,
+                this, &UIFileManager::sltHandleHidePanel);
+    }
+    if (m_pOptionsPanel)
+        connect(m_pOptionsPanel, &UIFileManagerOptionsPanel::sigHidePanel,
+                this, &UIFileManager::sltHandleHidePanel);
+
+    if (m_pLogPanel)
+        connect(m_pLogPanel, &UIFileManagerLogPanel::sigHidePanel,
+                this, &UIFileManager::sltHandleHidePanel);
+
+    if (m_pOperationsPanel)
+        connect(m_pOperationsPanel, &UIFileManagerOperationsPanel::sigHidePanel,
+                this, &UIFileManager::sltHandleHidePanel);
 }
 
@@ -484,7 +496,7 @@
     if (!pSenderAction)
         return;
-    UIFileManagerPanel* pPanel = 0;
+    UIDialogPanel* pPanel = 0;
     /* Look for the sender() within the m_panelActionMap's values: */
-    for (QMap<UIFileManagerPanel*, QAction*>::const_iterator iterator = m_panelActionMap.begin();
+    for (QMap<UIDialogPanel*, QAction*>::const_iterator iterator = m_panelActionMap.begin();
         iterator != m_panelActionMap.end(); ++iterator)
     {
@@ -527,4 +539,9 @@
     if (m_pHostFileTable)
         m_pHostFileTable->optionsUpdated();
+}
+
+void UIFileManager::sltHandleHidePanel(UIDialogPanel *pPanel)
+{
+    hidePanel(pPanel);
 }
 
@@ -678,5 +695,5 @@
     /* Save a list of currently visible panels: */
     QStringList strNameList;
-    foreach(UIFileManagerPanel* pPanel, m_visiblePanelsList)
+    foreach(UIDialogPanel* pPanel, m_visiblePanelsList)
         strNameList.append(pPanel->panelName());
     gEDataManager->setFileManagerVisiblePanels(strNameList);
@@ -707,5 +724,5 @@
     foreach(const QString strName, strNameList)
     {
-        foreach(UIFileManagerPanel* pPanel, m_panelActionMap.keys())
+        foreach(UIDialogPanel* pPanel, m_panelActionMap.keys())
         {
             if (strName == pPanel->panelName())
@@ -731,9 +748,9 @@
 }
 
-void UIFileManager::hidePanel(UIFileManagerPanel* panel)
+void UIFileManager::hidePanel(UIDialogPanel* panel)
 {
     if (panel && panel->isVisible())
         panel->setVisible(false);
-    QMap<UIFileManagerPanel*, QAction*>::iterator iterator = m_panelActionMap.find(panel);
+    QMap<UIDialogPanel*, QAction*>::iterator iterator = m_panelActionMap.find(panel);
     if (iterator != m_panelActionMap.end())
     {
@@ -745,9 +762,9 @@
 }
 
-void UIFileManager::showPanel(UIFileManagerPanel* panel)
+void UIFileManager::showPanel(UIDialogPanel* panel)
 {
     if (panel && panel->isHidden())
         panel->setVisible(true);
-    QMap<UIFileManagerPanel*, QAction*>::iterator iterator = m_panelActionMap.find(panel);
+    QMap<UIDialogPanel*, QAction*>::iterator iterator = m_panelActionMap.find(panel);
     if (iterator != m_panelActionMap.end())
     {
Index: /trunk/src/VBox/Frontends/VirtualBox/src/guestctrl/UIFileManager.h
===================================================================
--- /trunk/src/VBox/Frontends/VirtualBox/src/guestctrl/UIFileManager.h	(revision 76949)
+++ /trunk/src/VBox/Frontends/VirtualBox/src/guestctrl/UIFileManager.h	(revision 76950)
@@ -50,5 +50,5 @@
 class UIGuestControlConsole;
 class UIGuestControlInterface;
-class UIFileManagerPanel;
+class UIDialogPanel;
 class UIFileManagerLogPanel;
 class UIFileManagerOperationsPanel;
@@ -124,4 +124,5 @@
     /** Performs whatever necessary when some signal about option change has been receieved. */
     void sltHandleOptionsUpdated();
+    void sltHandleHidePanel(UIDialogPanel *pPanel);
 
 private:
@@ -157,6 +158,6 @@
      *  since some widgets are initilized with these options */
     void loadOptions();
-    void hidePanel(UIFileManagerPanel *panel);
-    void showPanel(UIFileManagerPanel *panel);
+    void hidePanel(UIDialogPanel *panel);
+    void showPanel(UIDialogPanel *panel);
     /** Makes sure escape key is assigned to only a single widget. This is done by checking
         several things in the following order:
@@ -189,6 +190,6 @@
     UIActionPool  *m_pActionPool;
     const bool     m_fShowToolbar;
-    QMap<UIFileManagerPanel*, QAction*> m_panelActionMap;
-    QList<UIFileManagerPanel*>          m_visiblePanelsList;
+    QMap<UIDialogPanel*, QAction*> m_panelActionMap;
+    QList<UIDialogPanel*>          m_visiblePanelsList;
     UIFileManagerOptionsPanel          *m_pOptionsPanel;
     UIFileManagerLogPanel              *m_pLogPanel;
@@ -196,5 +197,4 @@
     UIFileManagerOperationsPanel       *m_pOperationsPanel;
     friend class UIFileManagerOptionsPanel;
-    friend class UIFileManagerPanel;
     friend class UIFileManagerDialog;
 };
Index: /trunk/src/VBox/Frontends/VirtualBox/src/guestctrl/UIFileManagerLogPanel.cpp
===================================================================
--- /trunk/src/VBox/Frontends/VirtualBox/src/guestctrl/UIFileManagerLogPanel.cpp	(revision 76949)
+++ /trunk/src/VBox/Frontends/VirtualBox/src/guestctrl/UIFileManagerLogPanel.cpp	(revision 76950)
@@ -83,6 +83,6 @@
 *********************************************************************************************************************************/
 
-UIFileManagerLogPanel::UIFileManagerLogPanel(UIFileManager *pManagerWidget, QWidget *pParent)
-    : UIFileManagerPanel(pManagerWidget, pParent)
+UIFileManagerLogPanel::UIFileManagerLogPanel(QWidget *pParent /* = 0 */)
+    : UIDialogPanel(pParent)
     , m_pLogTextEdit(0)
 {
@@ -125,5 +125,5 @@
 void UIFileManagerLogPanel::retranslateUi()
 {
-    UIFileManagerPanel::retranslateUi();
+    UIDialogPanel::retranslateUi();
 
 }
Index: /trunk/src/VBox/Frontends/VirtualBox/src/guestctrl/UIFileManagerOperationsPanel.cpp
===================================================================
--- /trunk/src/VBox/Frontends/VirtualBox/src/guestctrl/UIFileManagerOperationsPanel.cpp	(revision 76949)
+++ /trunk/src/VBox/Frontends/VirtualBox/src/guestctrl/UIFileManagerOperationsPanel.cpp	(revision 76950)
@@ -308,7 +308,6 @@
 *********************************************************************************************************************************/
 
-UIFileManagerOperationsPanel::UIFileManagerOperationsPanel(UIFileManager *pManagerWidget,
-                                                                                   QWidget *pParent)
-    : UIFileManagerPanel(pManagerWidget, pParent)
+UIFileManagerOperationsPanel::UIFileManagerOperationsPanel(QWidget *pParent /* = 0 */)
+    : UIDialogPanel(pParent)
     , m_pScrollArea(0)
     , m_pContainerWidget(0)
@@ -380,5 +379,5 @@
 void UIFileManagerOperationsPanel::retranslateUi()
 {
-    UIFileManagerPanel::retranslateUi();
+    UIDialogPanel::retranslateUi();
 }
 
Index: /trunk/src/VBox/Frontends/VirtualBox/src/guestctrl/UIFileManagerOperationsPanel.h
===================================================================
--- /trunk/src/VBox/Frontends/VirtualBox/src/guestctrl/UIFileManagerOperationsPanel.h	(revision 76949)
+++ /trunk/src/VBox/Frontends/VirtualBox/src/guestctrl/UIFileManagerOperationsPanel.h	(revision 76950)
@@ -27,5 +27,5 @@
 /* GUI includes: */
 #include "UIGuestControlDefs.h"
-#include "UIFileManagerPanel.h"
+#include "UIDialogPanel.h"
 
 /* Forward declarations: */
@@ -42,7 +42,13 @@
 /** UIVMLogViewerPanel extension hosting a QListWidget which in turn has a special QWidget extension
   * to manage multiple CProgress instances. This is particulary used in monitoring file operations. */
-class UIFileManagerOperationsPanel : public UIFileManagerPanel
+class UIFileManagerOperationsPanel : public UIDialogPanel
 {
     Q_OBJECT;
+
+public:
+
+    UIFileManagerOperationsPanel(QWidget *pParent = 0);
+    virtual QString panelName() const /* override */;
+    void addNewProgress(const CProgress &comProgress);
 
 signals:
@@ -50,10 +56,4 @@
     void sigFileOperationComplete(QUuid progressId);
     void sigFileOperationFail(QString strErrorString, FileManagerLogType eLogType);
-
-public:
-
-    UIFileManagerOperationsPanel(UIFileManager *pManagerWidget, QWidget *pParent);
-    virtual QString panelName() const /* override */;
-    void addNewProgress(const CProgress &comProgress);
 
 protected:
Index: /trunk/src/VBox/Frontends/VirtualBox/src/guestctrl/UIFileManagerOptionsPanel.cpp
===================================================================
--- /trunk/src/VBox/Frontends/VirtualBox/src/guestctrl/UIFileManagerOptionsPanel.cpp	(revision 76949)
+++ /trunk/src/VBox/Frontends/VirtualBox/src/guestctrl/UIFileManagerOptionsPanel.cpp	(revision 76950)
@@ -32,7 +32,6 @@
 
 
-UIFileManagerOptionsPanel::UIFileManagerOptionsPanel(UIFileManager *pManagerWidget,
-                                                                               QWidget *pParent, UIFileManagerOptions *pFileManagerOptions)
-    : UIFileManagerPanel(pManagerWidget, pParent)
+UIFileManagerOptionsPanel::UIFileManagerOptionsPanel(QWidget *pParent, UIFileManagerOptions *pFileManagerOptions)
+    : UIDialogPanel(pParent)
     , m_pListDirectoriesOnTopCheckBox(0)
     , m_pDeleteConfirmationCheckBox(0)
@@ -181,5 +180,5 @@
 void UIFileManagerOptionsPanel::retranslateUi()
 {
-    UIFileManagerPanel::retranslateUi();
+    UIDialogPanel::retranslateUi();
     if (m_pListDirectoriesOnTopCheckBox)
     {
Index: unk/src/VBox/Frontends/VirtualBox/src/guestctrl/UIFileManagerPanel.cpp
===================================================================
--- /trunk/src/VBox/Frontends/VirtualBox/src/guestctrl/UIFileManagerPanel.cpp	(revision 76949)
+++ 	(revision )
@@ -1,124 +1,0 @@
-/* $Id$ */
-/** @file
- * VBox Qt GUI - UIVMLogViewer class implementation.
- */
-
-/*
- * Copyright (C) 2010-2019 Oracle Corporation
- *
- * This file is part of VirtualBox Open Source Edition (OSE), as
- * available from http://www.virtualbox.org. This file is free software;
- * you can redistribute it and/or modify it under the terms of the GNU
- * General Public License (GPL) as published by the Free Software
- * Foundation, in version 2 as it comes in the "COPYING" file of the
- * VirtualBox OSE distribution. VirtualBox OSE is distributed in the
- * hope that it will be useful, but WITHOUT ANY WARRANTY of any kind.
- */
-
-/* Qt includes: */
-#include <QComboBox>
-#include <QHBoxLayout>
-#include <QLabel>
-#include <QPlainTextEdit>
-#include <QTextCursor>
-#include <QToolButton>
-
-/* GUI includes: */
-#include "QIToolButton.h"
-#include "UIIconPool.h"
-#include "UIFileManager.h"
-#include "UIFileManagerPanel.h"
-#ifdef VBOX_WS_MAC
-# include "VBoxUtils-darwin.h"
-#endif
-
-
-UIFileManagerPanel::UIFileManagerPanel(UIFileManager *pManagerWidget, QWidget *pParent)
-    : QIWithRetranslateUI<QWidget>(pParent)
-    , m_pMainLayout(0)
-    , m_pCloseButton(0)
-    , m_pFileManager(pManagerWidget)
-{
-    prepare();
-}
-
-void UIFileManagerPanel::setCloseButtonShortCut(QKeySequence shortCut)
-{
-    if (!m_pCloseButton)
-        return;
-    m_pCloseButton->setShortcut(shortCut);
-}
-
-QHBoxLayout* UIFileManagerPanel::mainLayout()
-{
-    return m_pMainLayout;
-}
-
-void UIFileManagerPanel::prepare()
-{
-    prepareWidgets();
-    prepareConnections();
-    retranslateUi();
-}
-
-void UIFileManagerPanel::prepareWidgets()
-{
-    m_pMainLayout = new QHBoxLayout(this);
-    if (m_pMainLayout)
-    {
-#ifdef VBOX_WS_MAC
-        m_pMainLayout->setContentsMargins(5 /* since there is always a button */, 0, 10 /* standard */, 0);
-        m_pMainLayout->setSpacing(10);
-#else
-        m_pMainLayout->setContentsMargins(qApp->style()->pixelMetric(QStyle::PM_LayoutLeftMargin) / 2, 0,
-                                          qApp->style()->pixelMetric(QStyle::PM_LayoutRightMargin) / 2,
-                                          qApp->style()->pixelMetric(QStyle::PM_LayoutBottomMargin) / 2);
-        m_pMainLayout->setSpacing(qApp->style()->pixelMetric(QStyle::PM_LayoutHorizontalSpacing));
-#endif
-    }
-    m_pCloseButton = new QIToolButton;
-    if (m_pCloseButton)
-    {
-        m_pCloseButton->setIcon(UIIconPool::iconSet(":/close_16px.png"));
-        m_pMainLayout->addWidget(m_pCloseButton, 0, Qt::AlignLeft);
-    }
-}
-
-void UIFileManagerPanel::prepareConnections()
-{
-    if (m_pCloseButton)
-        connect(m_pCloseButton, &QIToolButton::clicked, this, &UIFileManagerPanel::hide);
-}
-
-void UIFileManagerPanel::retranslateUi()
-{
-    if (m_pCloseButton)
-        m_pCloseButton->setToolTip(UIFileManager::tr("Close the pane"));
-}
-
-bool UIFileManagerPanel::eventFilter(QObject *pObject, QEvent *pEvent)
-{
-    Q_UNUSED(pObject);
-    Q_UNUSED(pEvent);
-    /* Dont consume this event. Pass it back to Qt's event system: */
-    return false;
-}
-
-void UIFileManagerPanel::showEvent(QShowEvent *pEvent)
-{
-    QWidget::showEvent(pEvent);
-}
-
-void UIFileManagerPanel::hideEvent(QHideEvent *pEvent)
-{
-    /* Get focused widget: */
-    QWidget *pFocus = QApplication::focusWidget();
-    /* If focus-widget is valid and child-widget of search-panel,
-     * focus next child-widget in line: */
-    if (pFocus && pFocus->parent() == this)
-        focusNextPrevChild(true);
-    if (m_pFileManager)
-        m_pFileManager->hidePanel(this);
-
-    QWidget::hideEvent(pEvent);
-}
Index: unk/src/VBox/Frontends/VirtualBox/src/guestctrl/UIFileManagerPanel.h
===================================================================
--- /trunk/src/VBox/Frontends/VirtualBox/src/guestctrl/UIFileManagerPanel.h	(revision 76949)
+++ 	(revision )
@@ -1,75 +1,0 @@
-/* $Id$ */
-/** @file
- * VBox Qt GUI - UIVMLogViewer class declaration.
- */
-
-/*
- * Copyright (C) 2010-2019 Oracle Corporation
- *
- * This file is part of VirtualBox Open Source Edition (OSE), as
- * available from http://www.virtualbox.org. This file is free software;
- * you can redistribute it and/or modify it under the terms of the GNU
- * General Public License (GPL) as published by the Free Software
- * Foundation, in version 2 as it comes in the "COPYING" file of the
- * VirtualBox OSE distribution. VirtualBox OSE is distributed in the
- * hope that it will be useful, but WITHOUT ANY WARRANTY of any kind.
- */
-
-#ifndef FEQT_INCLUDED_SRC_guestctrl_UIFileManagerPanel_h
-#define FEQT_INCLUDED_SRC_guestctrl_UIFileManagerPanel_h
-#ifndef RT_WITHOUT_PRAGMA_ONCE
-# pragma once
-#endif
-
-/* Qt includes: */
-#include <QWidget>
-#include <QKeySequence>
-/* GUI includes: */
-#include "QIWithRetranslateUI.h"
-
-/* Forward declarations: */
-class QHBoxLayout;
-class QPlainTextEdit;
-class QTextDocument;
-class QIToolButton;
-class UIFileManager;
-
-/** QWidget extension acting as the base class for UIVMLogViewerXXXPanel widgets. */
-class UIFileManagerPanel : public QIWithRetranslateUI<QWidget>
-{
-    Q_OBJECT;
-
-public:
-
-    UIFileManagerPanel(UIFileManager *pManagerWidget, QWidget *pParent);
-    void setCloseButtonShortCut(QKeySequence shortCut);
-    virtual QString panelName() const = 0;
-
-protected:
-
-    virtual void prepare();
-    virtual void prepareWidgets();
-    virtual void prepareConnections();
-
-    /* Access functions for children classes. */
-    QHBoxLayout*               mainLayout();
-
-    /** Handles the translation event. */
-    void retranslateUi() /* override */;
-
-    /** Handles Qt @a pEvent, used for keyboard processing. */
-    bool eventFilter(QObject *pObject, QEvent *pEvent);
-    /** Handles the Qt show @a pEvent. */
-    void showEvent(QShowEvent *pEvent);
-    /** Handles the Qt hide @a pEvent. */
-    void hideEvent(QHideEvent *pEvent);
-
-private:
-
-    /** Holds the reference to VM Log-Viewer this panel belongs to. */
-    QHBoxLayout   *m_pMainLayout;
-    QIToolButton  *m_pCloseButton;
-    UIFileManager *m_pFileManager;
-};
-
-#endif /* !FEQT_INCLUDED_SRC_guestctrl_UIFileManagerPanel_h */
Index: /trunk/src/VBox/Frontends/VirtualBox/src/guestctrl/UIFileManagerSessionPanel.cpp
===================================================================
--- /trunk/src/VBox/Frontends/VirtualBox/src/guestctrl/UIFileManagerSessionPanel.cpp	(revision 76949)
+++ /trunk/src/VBox/Frontends/VirtualBox/src/guestctrl/UIFileManagerSessionPanel.cpp	(revision 76950)
@@ -216,6 +216,6 @@
 *********************************************************************************************************************************/
 
-UIFileManagerSessionPanel::UIFileManagerSessionPanel(UIFileManager *pManagerWidget, QWidget *pParent)
-    : UIFileManagerPanel(pManagerWidget, pParent)
+UIFileManagerSessionPanel::UIFileManagerSessionPanel(QWidget *pParent /* = 0 */)
+    : UIDialogPanel(pParent)
     , m_pSessionCreateWidget(0)
 {
@@ -262,5 +262,5 @@
 void UIFileManagerSessionPanel::retranslateUi()
 {
-    UIFileManagerPanel::retranslateUi();
+    UIDialogPanel::retranslateUi();
 
 }
Index: /trunk/src/VBox/Frontends/VirtualBox/src/medium/viso/UIVisoConfigurationPanel.h
===================================================================
--- /trunk/src/VBox/Frontends/VirtualBox/src/medium/viso/UIVisoConfigurationPanel.h	(revision 76949)
+++ /trunk/src/VBox/Frontends/VirtualBox/src/medium/viso/UIVisoConfigurationPanel.h	(revision 76950)
@@ -51,5 +51,4 @@
     void sigCustomVisoOptionsChanged(const QStringList &customVisoOptions);
 
-
 protected:
 

Index: /trunk/src/VBox/Frontends/VirtualBox/src/guestctrl/UIFileManagerLogPanel.h
===================================================================
--- /trunk/src/VBox/Frontends/VirtualBox/src/guestctrl/UIFileManagerLogPanel.h	(revision 76949)
+++ /trunk/src/VBox/Frontends/VirtualBox/src/guestctrl/UIFileManagerLogPanel.h	(revision 76950)
@@ -24,5 +24,5 @@
 /* GUI includes: */
 #include "UIGuestControlDefs.h"
-#include "UIFileManagerPanel.h"
+#include "UIDialogPanel.h"
 
 /* Forward declarations: */
@@ -30,6 +30,6 @@
 class UIFileManager;
 
-/** UIFileManagerPanel extension to display file manager logs. */
-class UIFileManagerLogPanel : public UIFileManagerPanel
+/** UIDialogPanel extension to display file manager logs. */
+class UIFileManagerLogPanel : public UIDialogPanel
 {
     Q_OBJECT;
@@ -37,5 +37,5 @@
 public:
 
-    UIFileManagerLogPanel(UIFileManager *pManagerWidget, QWidget *pParent);
+    UIFileManagerLogPanel(QWidget *pParent = 0);
     void appendLog(const QString &str, FileManagerLogType);
     virtual QString panelName() const /* override */;
Index: /trunk/src/VBox/Frontends/VirtualBox/src/guestctrl/UIFileManagerOptionsPanel.h
===================================================================
--- /trunk/src/VBox/Frontends/VirtualBox/src/guestctrl/UIFileManagerOptionsPanel.h	(revision 76949)
+++ /trunk/src/VBox/Frontends/VirtualBox/src/guestctrl/UIFileManagerOptionsPanel.h	(revision 76950)
@@ -23,5 +23,5 @@
 
 /* GUI includes: */
-#include "UIFileManagerPanel.h"
+#include "UIDialogPanel.h"
 
 /* Forward declarations: */
@@ -32,7 +32,7 @@
 class UIFileManagerOptions;
 
 /** UIFileManagerPanel extension to change file manager options. It directly
  *  modifies the options through the passed UIFileManagerOptions instance. */
-class UIFileManagerOptionsPanel : public UIFileManagerPanel
+class UIFileManagerOptionsPanel : public UIDialogPanel
 {
     Q_OBJECT;
@@ -40,6 +40,5 @@
 public:
 
-    UIFileManagerOptionsPanel(UIFileManager *pManagerWidget,
-                                           QWidget *pParent, UIFileManagerOptions *pFileManagerOptions);
+    UIFileManagerOptionsPanel(QWidget *pParent, UIFileManagerOptions *pFileManagerOptions);
     virtual QString panelName() const /* override */;
     /** Reads the file manager options and updates the widget accordingly. This functions is typically called
@@ -32,7 +32,7 @@
 class UIFileManagerOptions;
 
-/** UIFileManagerPanel extension to change file manager options. It directly
+/** UIDialogPanel extension to change file manager options. It directly
  *  modifies the options through the passed UIFileManagerOptions instance. */
Index: /trunk/src/VBox/Frontends/VirtualBox/src/guestctrl/UIFileManagerSessionPanel.h
===================================================================
--- /trunk/src/VBox/Frontends/VirtualBox/src/guestctrl/UIFileManagerSessionPanel.h	(revision 76949)
+++ /trunk/src/VBox/Frontends/VirtualBox/src/guestctrl/UIFileManagerSessionPanel.h	(revision 76950)
@@ -23,5 +23,5 @@
 
 /* GUI includes: */
-#include "UIFileManagerPanel.h"
+#include "UIDialogPanel.h"
 
 /* Forward declarations: */
@@ -30,6 +30,6 @@
 class UIGuestSessionCreateWidget;
 
-/** UIFileManagerPanel extension providing GUI for creating/stopping a guest session. */
-class UIFileManagerSessionPanel : public UIFileManagerPanel
+/** UIDialogPanel extension providing GUI for creating/stopping a guest session. */
+class UIFileManagerSessionPanel : public UIDialogPanel
 {
     Q_OBJECT;
@@ -37,5 +37,5 @@
 public:
 
-    UIFileManagerSessionPanel(UIFileManager *pManagerWidget, QWidget *pParent);
+    UIFileManagerSessionPanel(QWidget *pParent = 0);
     /** @name Enable/disable member widget wrt. guest session status.
       * @{ */